=begin
------------------------------------------------------------------------
Copyright 2008, TIG (c)
Permission to use, copy, modify, and distribute this software for any 
purpose, and currently without fee, is hereby granted, provided that  
this text and the above copyright (c) notice appear in all copies.
This software is provided "as is" and without any express or implied 
warranties, including, without limitation, the implied warranties of 
merchantability and fitness for a particular purpose.
------------------------------------------------------------------------
Name:          	Global_Material_Change.rb
Description:   	Changes Material Globally in Selection - 
				including mining into Groups/Definitions.
Author:       	TIG
Usage:			1. Select entities.
				[IF there's no selection ALL active entities are used] 
				2. Activate the script from the Plugins Menu.
				3. Choose Old Material [to be replaced].
				[<Default> = 'NO Material', << ALL >> = ALL Materials]
				4. Choose the desired New Material.
				[<Default> = 'no material']
History:		1.0 20080522	First issue.
=end
#-----------------------------------------------------------------------------
require 'sketchup.rb' 
class GlobalMaterial 
  def change(entity,old_mat,new_mat)  
    entity.definition.entities.each{|e|change(e,old_mat,new_mat)}if entity.typename=="ComponentInstance"
    entity.entities.each{|e|change(e,old_mat,new_mat)}if entity.typename=="Group"
    if old_mat=="<< Tous >>"
	  entity.material=new_mat
      entity.back_material=new_mat if entity.typename=="Face"
	else
	  entity.material=new_mat if entity.material==old_mat
      entity.back_material=new_mat if entity.typename=="Face" && entity.back_material==old_mat
	end#if
  end#def change 
  def process()
    # get the old and new materials
	model=Sketchup.active_model
	mats=model.materials
	matNames=["<Default>"]
	mats.each{|m|matNames.push(m.display_name)}
	matNames.push("<< Tous >>")
	mats=[nil]+mats.to_a+["<< Tous >>"]
	matList=matNames.join('|')
	# dialogs
	info=[matList]
    prompts=["Ancienne(s) texture(s)  fusionner : "]
    values=["<Default>"]
    results=inputbox(prompts,values,info,"Fusion des textures")
    return nil if ! results
	omat=results[0]
	old_mat=mats[matNames.index(omat)]
	if omat=="<< Tous >>"
	  return nil if UI.messagebox("Ce script affecte TOUTES les entits du dessin !\nContinuer ?",MB_YESNO,"ALL ?")==7### 6=YES 7=NO
	end#if
	#
	matNames=matNames-["<< Tous >>"]
	mats=mats-["<< Tous >>"]
	matList=matNames.join('|')
	info=[matList]
    prompts=["Nouvelle texture : "]
    values=["<Default>"]
    results=inputbox(prompts,values,info,"Fusion des textures")
    return nil if ! results
	nmat=results[0]
	new_mat=mats[matNames.index(nmat)]
	# now work on ALL entities
    if model.selection[0]
	  model.selection.each{|e|change(e,old_mat,new_mat)}
	else
	  model.active_entities.each{|e|change(e,old_mat,new_mat)}
	end#if
  end#def process 
end#class
#-----------------------------------------------------------------------
def global_material_change
  model=Sketchup.active_model
  model.start_operation("Global Material Change")
    if ! model.selection[0]
      return nil if UI.messagebox("Ce script affecte TOUTES les entits du dessin !\nContinuer ?",MB_YESNO,"ALL ?")==7### 6=YES 7=NO
    end#if
    GlobalMaterial.new.process
  model.commit_operation
end#def
#-----------------------------------------------------------------------
is_this_file=File.basename(__FILE__)
if not file_loaded?(is_this_file)
  UI.menu("Plugins").add_item("Fusion des textures"){global_material_change}
end#if
#-----------------------------------------------------------------------
file_loaded(is_this_file)
